"""The Hypermodern Python Project."""

# TODO: Change to single source version strategy.
#   https://packaging.python.org/en/latest/guides/single-sourcing-package-version/#single-sourcing-the-package-version
#   https://docs.python.org/3.11/library/importlib.metadata.html#module-importlib.metadata
__version__ = "0.6.0"
